<?php

namespace AdminModule\Forms;

use Nette\Application\UI;
use Nette\Forms\Form;
use Nette\Mail\Mail;
use Nette\ComponentModel\IContainer;
use Nette\Utils\Strings;
use Nette\Image;

class ArticleForm extends UI\Form {

    public function __construct(IContainer $parent = NULL, $name = NULL) {
	parent::__construct($parent, $name);
        
        $this->addText('nazev','Nadpis')
                ->addRule(Form::FILLED, 'Musí být zadán nadpis');
        
        $category = array("Areály" => \ArealyModel::getInstance()->selectAllForm());
        $this->addSelect('id_areal', 'Areál', $category)
                ->setPrompt('Vyberte areál...')
                ->addRule(Form::FILLED, 'Musí být vybrán areál');
        
        $this->addTextArea('html', 'Text')
                ->addRule(Form::FILLED, 'Musí být zadán text')
                ->setAttribute('class','tinyMce');
        
        $this->addUpload('picture', 'Obrázek k novince');
        
        // galerie
        $galerie = array(0 => 'Vyberte galerii...', "Fotogalerie" => \GaleriesModel::getInstance()->selectAllForm());
        $this->addSelect('id_galery', 'Připojit galerii', $galerie);
        
        $this->addHidden('id_article');
        
	$this->addSubmit('send', 'Odeslat')
                ->setAttribute('class','btn btn-success');
	$this->onSuccess[] = array($this, 'formSubmited');
    }

    public function formSubmited($form) {
        
        $data = $form->getValues();
        $user = \UserModel::getInstance()->user($this->getPresenter()->getUser()->getId());
        
        if($data['id_article']==0) {
         
        // NOVÝ ČLÁNEK  
            
            $zdroj = array(
                'id_user'   => $user['id_user'],
                'nazev'     => $data['nazev'],
                'url'       => Strings::webalize($data['nazev']),
                'html'      => $data['html'],
                'id_galery' => $data['id_galery'],
                'id_areal'  => $data['id_areal'],
                'datum'     => new \DateTime
            );
            
            
            $id_posledni = \ArticlesModel::getInstance()->articleAdd($zdroj);
            
            if(isset($data['picture'])) {
                if($data['picture']->isOk()) {
                    $obrazek = Image::fromFile($data['picture']);
                    $obrazek->resize(115,NULL);
                    $obrazek->save(WWW_DIR.'/pictures/jpg/n_'.$id_posledni.'.jpg');
                }
            }
            
            $this->getPresenter()->flashMessage('Novinka byla úspěšně přidána','success');
            $this->getPresenter()->redirect('Admin:areal',$data['id_areal']);
            
        }else{
            
        // UPRAVIT ČLÁNEK
            
            $zdroj = array(
                'id_user'   => $user['id_user'],
                'nazev'     => $data['nazev'],
                'url'       => Strings::webalize($data['nazev']),
                'html'      => $data['html'],
                'id_areal'  => $data['id_areal'],
                'id_galery' => $data['id_galery']
            );
            
            if(isset($data['picture'])) {
                if($data['picture']->isOk()) {
                    $obrazek = Image::fromFile($data['picture']);
                    $obrazek->resize(115,NULL);
                    $obrazek->save(WWW_DIR.'/pictures/jpg/n_'.$id_posledni.'.jpg');
                }
            }
            
            \ArticlesModel::getInstance()->articleUpd($data['id_article'],$zdroj);
            $this->getPresenter()->flashMessage('Novinka byla úspěšně upravena','success');
            $this->getPresenter()->redirect('Admin:areal',$data['id_areal']);
            
        }
        
    }

}
