<?php

namespace AdminModule\Forms;

use Nette\Application\UI;
use Nette\Forms\Form;
use Nette\Image;
use Nette\ComponentModel\IContainer;

\Nette\Forms\Controls\MultiUploadControl::register();

class BannerForm extends UI\Form {

    public function __construct(IContainer $parent = NULL, $name = NULL) {
	parent::__construct($parent, $name);
        
        $this->addText('nazev','Název')
                ->addRule(Form::FILLED, 'Musí být zadán název');
        
        $this->addText('url','Odkaz (včetně http://')
                ->setDefaultValue('http://')
                ->addRule(Form::FILLED, 'Musí být zadán odkaz');
        
        $this->addUpload('picture', 'Banner');
        
        $this->addCheckbox('kino','Banner pro kino');
        
        $items = array();
        $udalosti = \UdalostiModel::getInstance()->selectAll();
        foreach($udalosti as $key => $udalost) {
            $items[$udalost['nazev']] = \TerminyModel::getInstance()->selectAllForm($udalost['id_udalost']);
        }
        
        $this->addSelect('id_termin','Událost',$items)
                ->setPrompt('Vyberte')
                ->setDefaultValue(0);
        
        $this->addText('platnost','Zobrazit do:')
                ->addRule(Form::FILLED, 'Musí být zadáno datum a čas')
                ->setHtmlId('datetime');
        
        $this->addHidden('id_banner');
        
	$this->addSubmit('send', 'Odeslat')
                ->setAttribute('class','btn btn-success');
	$this->onSuccess[] = array($this, 'formSubmited');
    }

    public function formSubmited($form) {
        
        $data = $form->getValues();
        $user = \UserModel::getInstance()->user($this->getPresenter()->getUser()->getId());
        
        if($data['id_banner']==0) {
         
            if(isset($data['id_termin'])) {
                $id_termin = $data['id_termin'];
            }else{
                $id_termin = 0;
            }
            
        // NOVÝ BANNER    
            
            $zdroj = array(
                'nazev'      => $data['nazev'],
                'url'        => $data['url'],
                'platnost'   => $data['platnost'],
                'id_termin'  => $id_termin,
                'kino'       => $data['kino']
            );
            $id_banner = \BanneryModel::getInstance()->bannerAdd($zdroj);
            
            // přidání fotek
           if($data['picture']->isOk()) {
                $obrazek = Image::fromFile($data['picture']);
                if($data['kino']==1) {
                    $obrazek->resize(700,255,Image::EXACT);
                    $obrazek->save(WWW_DIR.'/pictures/jpg/b_'.$id_banner.'_b.jpg');
                }else{
                    $obrazek->resize(418,240,Image::EXACT);
                    $obrazek->save(WWW_DIR.'/pictures/jpg/b_'.$id_banner.'_b.jpg');
                    $obrazek->resize(196,113,Image::EXACT);
                    $obrazek->save(WWW_DIR.'/pictures/jpg/b_'.$id_banner.'_s.jpg');
                }
            }
            
            $this->getPresenter()->flashMessage('Banner byl úspěšně přidán','success');
            $this->getPresenter()->redirect('Admin:bannery');
            
            
        }else{
            
        // UPRAVIT GALERII
            
            if(isset($data['id_termin'])) {
                $id_termin = $data['id_termin'];
            }else{
                $id_termin = 0;
            }
            
            $zdroj = array(
                'nazev'      => $data['nazev'],
                'url'        => $data['url'],
                'platnost'   => $data['platnost'],
                'id_termin'  => $id_termin,
                'kino'       => $data['kino']
            );
            
            \BanneryModel::getInstance()->bannerUpd($data['id_banner'],$zdroj);
            
            // přidání fotek
           if($data['picture']->isOk()) {
                $obrazek = Image::fromFile($data['picture']);
                if($data['kino']==1) {
                    $obrazek->resize(700,255,Image::EXACT);
                    $obrazek->save(WWW_DIR.'/pictures/jpg/b_'.$data['id_banner'].'_b.jpg');
                }else{
                    $obrazek->resize(418,240,Image::EXACT);
                    $obrazek->save(WWW_DIR.'/pictures/jpg/b_'.$data['id_banner'].'_b.jpg');
                    $obrazek->resize(196,113,Image::EXACT);
                    $obrazek->save(WWW_DIR.'/pictures/jpg/b_'.$data['id_banner'].'_s.jpg');
                }
            }
            
            $this->getPresenter()->flashMessage('Banner byl úspěšně upraven','success');
            $this->getPresenter()->redirect('this');
            
        }
        
    }

}
