<?php

namespace AdminModule\Forms;

use Nette\Application\UI;
use Nette\Forms\Form;
use Nette\Image;
use Nette\ComponentModel\IContainer;

class ExportForm extends UI\Form {

    public function __construct(IContainer $parent = NULL, $name = NULL) {
	parent::__construct($parent, $name);
        
        $this->addText('datum_od','Od:')
                ->setAttribute('class','date');
        
        $this->addText('datum_do','Do:')
                ->setAttribute('class','date');
        
        // sportoviště
        $sportoviste = array(0 => "Všechna sportoviště","Vyberte sportoviště" => \SportovisteModel::getInstance()->selectAllForm());
        $this->addSelect('id_sportoviste', 'Sportoviště', $sportoviste);
        
        $prodane = array(1 => 'Prodané i neprodané',2 => 'Pouze prodané',3 => 'Pouze neprodané');
        $this->addSelect('prodane','Zahrnout rezervace',$prodane);
        
	$this->addSubmit('send', 'Vytvořit přehled')
                ->setAttribute('class','btn btn-success');
	$this->onSuccess[] = array($this, 'formSubmited');
    }

    public function formSubmited($form) {
        
        $data = $form->getValues();
        $datum_od       = $data['datum_od'];
        $datum_do       = $data['datum_do'];
        
        if($data['prodane']==1){
            $prodane = null;
        }elseif($data['prodane']==2){
            $prodane = 1;
        }elseif($data['prodane']==3){
            $prodane = 0;
        }
        
        // EXPORT DO EXCELU
        
        include LIBS_DIR.'/phpexcel/PHPExcel.php';
        $export = new \PHPExcel;
        
        $export->setActiveSheetIndex(0);
        
        $list = $export->getActiveSheet();
        
        $list->getColumnDimension('A')->setWidth('20');
        $list->getColumnDimension('B')->setWidth('20');
        $list->getColumnDimension('C')->setWidth('20');
        $list->getColumnDimension('D')->setWidth('20');
        $list->getColumnDimension('E')->setWidth('20');
        $list->getColumnDimension('F')->setWidth('20');
        $list->getColumnDimension('G')->setWidth('10');
        $list->getColumnDimension('H')->setWidth('20');
        
        $list->getStyle('A1:H1')
                ->getBorders()
                ->getBottom()
                ->setBorderStyle(\PHPExcel_Style_Border::BORDER_THICK);
        
        $list->setCellValue('A1', 'Zákazník');
        $list->setCellValue('B1', 'Datum');
        $list->setCellValue('C1', 'Čas');
        $list->setCellValue('D1', 'Sportoviště');
        $list->setCellValue('E1', 'Prodejce');
        $list->setCellValue('F1', 'Způsob platby');
        $list->setCellValue('G1', 'Cena');
        $list->setCellValue('H1', 'Poznámka');
        
        // rezervace výpis
        $id_sportoviste = $data['id_sportoviste'];
        $radek = 2;
        $rezervace = \RezervaceModel::getInstance()->selectAll(null,null,$id_sportoviste,Date("Y-m-d",strtotime($datum_od)),Date("Y-m-d",strtotime($datum_do)),null,$prodane);
        foreach($rezervace as $key => $item) {
            // zajistíme aby se správně zobrazovalo jméno telefon a email ať už jde o rezervace provedené uživatelem nebo správcem
            $jmeno   = '';
            $email   = '';
            $telefon = '';
            if($item['id_user']!=0) {
                $uzivatel = \UserModel::getInstance()->user($item['id_user']);
                $jmeno   = $uzivatel['prijmeni'].' '.$uzivatel['jmeno'];
            }else{
                $jmeno   = $item['jmeno'];
            }
            
            $cas      = \CasyModel::getInstance()->cas($item['id_cas']);
            $prodejce = \UserModel::getInstance()->user($item['id_prodejce']);
            $platba   = \PlatbyModel::getInstance()->platba($item['id_platba']);
            $sportoviste = \SportovisteModel::getInstance()->sportoviste($item['id_sportoviste']);
            
            $storno   = '';
            if($item['storno']!=0){
                $storner = \UserModel::getInstance()->user($item['storno']);
                $storno = 'Storno ('.$storner['prijmeni'].')';
            }
            
            $list->setCellValueByColumnAndRow(0, $radek, $jmeno);
            $list->setCellValueByColumnAndRow(1, $radek, Date("d.m.Y", strtotime($item['datum'])));
            $list->setCellValueByColumnAndRow(2, $radek, $cas['nazev']);
            $list->setCellValueByColumnAndRow(3, $radek, $sportoviste['nazev']);
            $list->setCellValueByColumnAndRow(4, $radek, $prodejce['prijmeni']);
            $list->setCellValueByColumnAndRow(5, $radek, $platba['nazev']);
            $list->setCellValueByColumnAndRow(6, $radek, $platba['value']);
            $list->setCellValueByColumnAndRow(7, $radek, $storno);
            
            $radek++;
        }
        
        // uložení do databáze
        $zdroj = array(
            'id_user'        => $this->getPresenter()->getUser()->getId(),
            'id_sportoviste' => $id_sportoviste,
            'datum'          => new \DateTime,
            'datum_od'       => $datum_od,
            'datum_do'       => $datum_do,
            'prodane'        => $data['prodane']
        );
        $id_export = \PlatbyModel::getInstance()->exportAdd($zdroj);
        
        $newExcelWriter = new \PHPExcel_Writer_Excel5($export);
        $newExcelWriter->save('./export/'.$id_export.'.xls');
        
        $this->getPresenter()->flashMessage('Přehled byl úspěšně vytvořen, nyní jej můžete stáhnout níže','success');
        $this->getPresenter()->redirect('this');
        
    }

}
