<?php

namespace AdminModule\Forms;

use Nette\Application\UI;
use Nette\Forms\Form;
use Nette\Mail\Mail;
use Nette\ComponentModel\IContainer;

class ProdejForm extends UI\Form {

    public function __construct(IContainer $parent = NULL, $name = NULL) {
	parent::__construct($parent, $name);
        
        // vybereme platbu podle sportoviste
        $platby = array("Zboží / Služba" => \PlatbyModel::getInstance()->selectAllForm(null,$this->getPresenter()->id_areal));
        $this->addSelect('id_platba', 'Položka', $platby)
                ->setPrompt('Vyberte položku k prodeji')
                ->addRule(Form::FILLED, 'Musí být vybrána položka k prodeji');
        
        $this->addText('mnozstvi','Množství')
                ->setType('number')
                ->setDefaultValue('1');
        
        $uzivatel = \UserModel::getInstance()->user($this->getPresenter()->getUser()->getId());
        if($uzivatel['faktura']==1) {
            $this->addCheckbox('faktura','Platba na fakturu');
        }
        if($uzivatel['karta']==1) {
            $this->addCheckbox('karta','Platba kartou');
        }
        
        $this->addHidden('id_prodej');
        
	$this->addSubmit('send', 'Prodat')
                ->setAttribute('class','btn btn-success')
                ->setAttribute('onclick', 'return confirm("Opravdu chcete tuto položku prodat?")');
	$this->onSuccess[] = array($this, 'formSubmited');
    }

    public function formSubmited($form) {
        
        $data = $form->getValues();
        $user = \UserModel::getInstance()->user($this->getPresenter()->getUser()->getId());
        
        if(isset($data['faktura']) AND $data['faktura']==1) {
            $faktura = 1;
        }else{
            $faktura = 0;
        }
        
        if(isset($data['karta']) AND $data['karta']==1) {
            $karta = 1;
        }else{
            $karta = 0;
        }
        
        if($data['id_prodej']==0) {
         
        // NOVÝ PRODEJ    
            
            $platba = \PlatbyModel::getInstance()->platba($data['id_platba']);
            
            $value = $data['mnozstvi']*$platba['value'];
            
            $zdroj = array(
                'id_user'   => $user['id_user'],
                'id_platba' => $data['id_platba'],
                'id_areal'  => $this->getPresenter()->id_areal,
                'datum'     => new \DateTime,
                'nazev'     => $platba['nazev'],
                'mnozstvi'  => $data['mnozstvi'],
                'karta'     => $karta,
                'faktura'   => $faktura,
                'value'     => $value
            );
            
            \ProdejeModel::getInstance()->prodejAdd($zdroj);
            $this->getPresenter()->flashMessage('Cena celkem: <strong style="color: #000000;font-size: 130%;">'.$value.' Kč</strong>','success');
            
            // načte proměnné pro tisk
            $this->getPresenter()->template->cena        = $value;
            $this->getPresenter()->template->nazev       = $platba['nazev'];
            $this->getPresenter()->template->mnozstvi    = $data['mnozstvi'];
            $this->getPresenter()->template->id_prodejce = $this->getPresenter()->getUser()->getId();
            $this->getPresenter()->template->karta       = $karta;
            $this->getPresenter()->template->faktura     = $faktura;
          
            
        }else{
            
        // UPRAVIT PRODEJ
            
            $platba = \PlatbyModel::getInstance()->platba($data['id_platba']);
            
            $value = $data['mnozstvi']*$platba['value'];
            
            $zdroj = array(
                'id_platba' => $data['id_platba'],
                'nazev'     => $platba['nazev'],
                'mnozstvi'  => $data['mnozstvi'],
                'karta'     => $karta,
                'faktura'   => $faktura,
                'value'     => $value
            );
            
            \ProdejeModel::getInstance()->prodejUpd($data['id_prodej'],$zdroj);
            $this->getPresenter()->flashMessage('Prodej byl úspěšně upraven','success');
            $this->getPresenter()->redirect('this');
            
        }
        
    }

}
