<?php

namespace AdminModule;

use Nette\Web\User;
use Nette\Environment;
use Nette\Mail\Mail;
use Nette\String;

class AdminPresenter extends BasePresenter {
    
    // OVĚŘENÍ, ŽE SE JEDNÁ O ADMINA, JINAK => HOMEPAGE 
    
    public function startup() {
        parent::startup();
        
        // načte uživatele
        $user = $this->getUser();
        
        // OVĚŘENÍ PŘIHLÁŠENÉHO UŽIVATELE
        if(!$user->isInRole('admin')){
            $this->redirect('Login:default');
        }
        
    }
    
// ÚVODNÍ STRÁNKA  

    // úvodní stránka areálu
    public function actionAreal($id_areal = 1) {
        
        $areal = \ArealyModel::getInstance()->areal($id_areal);
        
        $articles = \ArticlesModel::getInstance()->selectAll(0,10,$id_areal);
        foreach ($articles as $key => $article) {
            $autor = \UserModel::getInstance()->user($article['id_user']);
            $articles[$key]['autor'] = $autor['prijmeni'];
        }
        $this->template->articles = $articles;
        
        $pages = \PagesModel::getInstance()->selectAll(0,10,null,$id_areal);
        foreach ($pages as $key => $page) {
            $autor = \UserModel::getInstance()->user($page['id_user']);
            $pages[$key]['autor'] = $autor['prijmeni'];
        }
        $this->template->pages  = $pages;
        
        $bannery = \BanneryModel::getInstance()->selectAll(0,10);
        $this->template->bannery  = $bannery;
        
        $galeries = \GaleriesModel::getInstance()->selectAll(0,10,$id_areal);
        $this->template->galeries  = $galeries;
        
        $ceniky = \CenikyModel::getInstance()->selectAllKat($id_areal);
        $this->template->ceniky  = $ceniky;
        
        $rozvrhy = \RozvrhyModel::getInstance()->selectAll(null,null,$id_areal);
        $this->template->rozvrhy  = $rozvrhy;
        
        $this->template->arealy = \ArealyModel::getInstance()->selectAll(null,null,null,1);
        $this->template->areal  = $areal;
        
        $form = new Forms\ArealForm($this, 'arealForm');
        $form->setDefaults($areal);
    }
    
// UŽIVATELÉ
    
    // výpis uživatelů
    public function actionUsers($search = null,$id_role = null) {
        $vp        = new \VisualPaginator($this,'vp');
        $paginator = $vp->getPaginator();
        $paginator->itemsPerPage = 20;
        $paginator->itemCount = count(\UserModel::getInstance()->listUser());
        if(isset($search)) {
            $users = \UserModel::getInstance()->search($search);
        }else{
            $users = \UserModel::getInstance()->listUser($paginator->offset,$paginator->itemsPerPage,$id_role);
        }
        $this->template->users = $users;
    }
    
    // přidání uživatele
    public function actionUserAdd(){
        $form = new \Forms\UserForm($this, 'form');
        $this->template->title = 'Nový uživatel';
        $this->setView('form');
    }
    
    // upraví uživatele
    public function actionUserUpd($id_user){
        $uzivatel = \UserModel::getInstance()->user($id_user);
        $form = new \Forms\UserForm($this, 'form');
        $omezeni = \RezervaceModel::getInstance()->selectOmezeniForm($id_user);
        $spojeni = array();
        foreach($omezeni as $omezenko) {
            $spojeni[] = $omezenko['id_areal'];
        }
        
        $data = array(
            'id_user'    => $uzivatel['id_user'],
            'id_role'    => $uzivatel['id_role'],
            'email'      => $uzivatel['email'],
            'password'   => $uzivatel['password'],
            'jmeno'      => $uzivatel['jmeno'],
            'prijmeni'   => $uzivatel['prijmeni'],
            'telefon'    => $uzivatel['telefon'],
            'ucetni'     => $uzivatel['ucetni'],
            'faktura'    => $uzivatel['faktura'],
            'cela_plocha' => $uzivatel['cela_plocha'],
            'karta'      => $uzivatel['karta'],
            'omezeni'    => $spojeni
        );
        $form->setDefaults($data);
        $this->template->title = 'Editace uživatele';
        $this->setView('form');
    }
    
    // odstraní uživatele
    public function actionUserDel($id_user){
        $uzivatel = \UserModel::getInstance()->deleteUser($id_user);
        $this->flashMessage('Uživatel byl úspěšně odstraněn','success');
        $this->redirect('Admin:users');
    }
    
// BANNERY
    
    // výpis bannerů
    public function actionBannery($search = null) {
        $vp        = new \VisualPaginator($this,'vp');
        $paginator = $vp->getPaginator();
        $paginator->itemsPerPage = 20;
        $paginator->itemCount = count(\BanneryModel::getInstance()->selectAll());
        $bannery = \BanneryModel::getInstance()->selectAll($paginator->offset,$paginator->itemsPerPage);
        $this->template->bannery = $bannery;
    }
    
    // přidání banneru
    public function actionBannerAdd(){
        $form = new \AdminModule\Forms\BannerForm($this, 'form');
        $this->template->title = 'Nový banner';
        $this->setView('form');
    }
    
    // upraví banner
    public function actionBannerUpd($id_banner){
        $banner = \BanneryModel::getInstance()->banner($id_banner);
        $form = new \AdminModule\Forms\BannerForm($this, 'form');
        $form->setDefaults($banner);
        $this->template->title = 'Editace banneru';
        $this->setView('form');
    }
    
    // odstraní banner
    public function actionBannerDel($id_banner){
        $banner = \BanneryModel::getInstance()->bannerDel($id_banner);
        $this->flashMessage('Banner byl úspěšně odstraněn','success');
        $this->redirect('Admin:bannery');
    }    

// NASTAVENÍ
    
    // upraví nastavení
    public function actionSettings(){
        $nastaveni = \NastaveniModel::getInstance()->selectAll();
        $form = new Forms\NastaveniForm($this, 'form');
        $form->setDefaults($nastaveni);
        $this->template->title = 'Úprava nastavení';
        $this->setView('form');
    }
    
// STRÁNKY
    
    // výpis stránek
    public function actionPages() {
        $vp        = new \VisualPaginator($this,'vp');
        $paginator = $vp->getPaginator();
        $paginator->itemsPerPage = 20;
        $paginator->itemCount = count(\PagesModel::getInstance()->selectAll(null,null,null,0));
        $pages = \PagesModel::getInstance()->selectAll($paginator->offset,$paginator->itemsPerPage,null,0);
        foreach($pages as $key => $page) {
            $user = \UserModel::getInstance()->user($page['id_user']);
            $pages[$key]['autor'] = $user['prijmeni'];
        }
        $this->template->pages = $pages;
    }
    
    // přidání stránky
    public function actionPageAdd(){
        $form = new Forms\PageForm($this, 'form');
        $this->template->title = 'Nová stránka';
        $this->setView('form');
    }
    
    // upraví stránku
    public function actionPageUpd($id_page){
        $page = \PagesModel::getInstance()->page($id_page);
        $form = new Forms\PageForm($this, 'form');
        $form->setDefaults($page);
        $this->template->title = 'Editace stránky';
        $this->setView('form');
    }
    
    // odstraní stránku
    public function actionPageDel($id_page){
        $page = \PagesModel::getInstance()->pageDel($id_page);
        $this->flashMessage('Stránka byla úspěšně odstraněna','success');
        $this->redirect('Admin:pages');
    }    
    
// GALERIE A FOTKY
    
    // výpis galerií
    public function actionGaleries() {
        $vp        = new \VisualPaginator($this,'vp');
        $paginator = $vp->getPaginator();
        $paginator->itemsPerPage = 20;
        $paginator->itemCount = count(\GaleriesModel::getInstance()->selectAll());
        $galeries = \GaleriesModel::getInstance()->selectAll($paginator->offset,$paginator->itemsPerPage);
        foreach($galeries as $key => $galery) {
            $user = \UserModel::getInstance()->user($galery['id_user']);
            $galeries[$key]['autor'] = $user['prijmeni'];
            $galeries[$key]['pocet'] = count(\PicturesModel::getInstance()->selectAll(null,null,$galery['id_galery']));
        }
        $this->template->galeries = $galeries;
    }
    
    // přidání galerie
    public function actionGaleryAdd(){
        $form = new Forms\GaleryForm($this, 'form');
        $this->template->title = 'Nová galerie';
        $this->template->info  = '<p><i>Nahrání více souborů může trvat i několik minut v závislosti na kvalitě internetového připojení.</i></p>';
        $this->setView('form');
    }
    
    // upraví galerii
    public function actionGaleryUpd($id_galery){
        $galery = \GaleriesModel::getInstance()->galery($id_galery);
        $pictures = \PicturesModel::getInstance()->selectAll(null,null,$id_galery);
        $form = new Forms\GaleryForm($this, 'form');
        $form->setDefaults($galery);
        $this->template->title    = 'Editace galerie';
        $this->template->pictures = $pictures;
    }
    
    // odstraní galerii
    public function handleGaleryDel($id_galery){
        $galery = \GaleriesModel::getInstance()->galeryDel($id_galery);
        $this->flashMessage('Galerie byla úspěšně odstraněna','success');
        $this->redirect('this');
    }   
    
    // odstraní fotografii
    public function handlePictureDel($id_picture){
        $picture = \PicturesModel::getInstance()->pictureDel($id_picture);
        $this->flashMessage('Fotografie byla úspěšně odstraněna','success');
        $this->redirect('this');
    }      
    
// UDÁLOSTI
    
    // výpis událostí
    public function actionEvents() {
        $vp        = new \VisualPaginator($this,'vp');
        $paginator = $vp->getPaginator();
        $paginator->itemsPerPage = 20;
        $paginator->itemCount = count(\EventsModel::getInstance()->selectAll());
        $events = \EventsModel::getInstance()->selectAll($paginator->offset,$paginator->itemsPerPage);
        foreach($events as $key => $event) {
            $user = \UserModel::getInstance()->user($event['id_user']);
            $events[$key]['autor'] = $user['prijmeni'];
        }
        $this->template->events = $events;
    }
    
    // přidání události
    public function actionEventAdd(){
        $form = new Forms\EventForm($this, 'form');
        $this->template->title = 'Nová událost';
        $this->setView('form');
    }
    
    // upraví událost
    public function actionEventUpd($id_event){
        $event = \EventsModel::getInstance()->event($id_event);
        $form = new Forms\EventForm($this, 'form');
        $form->setDefaults($event);
        $this->template->title = 'Editace události';
        $this->setView('form');
    }
    
    // odstraní událost
    public function actionEventDel($id_event){
        $event = \EventsModel::getInstance()->eventDel($id_event);
        $this->flashMessage('Událost byla úspěšně odstraněna','success');
        $this->redirect('Admin:events');
    }            
    
// ČLÁNKY
    
    // výpis článků
    public function actionArticles() {
        $vp        = new \VisualPaginator($this,'vp');
        $paginator = $vp->getPaginator();
        $paginator->itemsPerPage = 20;
        $paginator->itemCount = count(\ArticlesModel::getInstance()->selectAll());
        $articles = \ArticlesModel::getInstance()->selectAll($paginator->offset,$paginator->itemsPerPage);
        foreach($articles as $key => $article) {
            $user      = \UserModel::getInstance()->user($article['id_user']);
            $areal     = \ArealyModel::getInstance()->areal($article['id_areal']); 
            $articles[$key]['autor']     = $user['prijmeni'];
            $articles[$key]['areal']     = $areal['nazev'];
        }
        $this->template->articles = $articles;
    }
    
    // přidání článku
    public function actionArticleAdd(){
        $form = new Forms\ArticleForm($this, 'form');
        $this->template->title = 'Přidat novinku';
        $this->setView('form');
    }
    
    // upraví článek
    public function actionArticleUpd($id_article){
        $article = \ArticlesModel::getInstance()->article($id_article);
        $form = new Forms\ArticleForm($this, 'form');
        $form->setDefaults($article);
        $this->template->title = 'Editace novinky';
        $this->setView('form');
    }
    
    // odstraní článek
    public function actionArticleDel($id_article){
        $article = \ArticlesModel::getInstance()->articleDel($id_article);
        $this->flashMessage('Novinka byla úspěšně odstraněna','success');
        $this->redirect('Admin:articles');
    }     
    
// KATEGORIE
    
    // výpis kategorií
    public function actionCategories() {
        $vp        = new \VisualPaginator($this,'vp');
        $paginator = $vp->getPaginator();
        $paginator->itemsPerPage = 20;
        $paginator->itemCount = count(\CategoriesModel::getInstance()->selectAll());
        $categories = \CategoriesModel::getInstance()->selectAll($paginator->offset,$paginator->itemsPerPage);
        $this->template->categories = $categories;
    }
    
    // přidání kategorie
    public function actionCategoryAdd(){
        $form = new Forms\CategoryForm($this, 'form');
        $this->template->title = 'Nová kategorie';
        $this->setView('form');
    }
    
    // upraví kategorii
    public function actionCategoryUpd($id_category){
        $category = \CategoriesModel::getInstance()->category($id_category);
        $form = new Forms\CategoryForm($this, 'form');
        $form->setDefaults($category);
        $this->template->title = 'Editace kategorie';
        $this->setView('form');
    }
    
    // odstraní kategorii
    public function actionCategoryDel($id_category){
        $category = \CategoriesModel::getInstance()->categoryDel($id_category);
        $this->flashMessage('Kategorie byla úspěšně odstraněna','success');
        $this->redirect('Admin:categories');
    }         

// AREÁLY
    
    // výpis areálů
    public function actionArealy() {
        $vp        = new \VisualPaginator($this,'vp');
        $paginator = $vp->getPaginator();
        $paginator->itemsPerPage = 20;
        $paginator->itemCount = count(\ArealyModel::getInstance()->selectAll());
        $arealy = \ArealyModel::getInstance()->selectAll($paginator->offset,$paginator->itemsPerPage);
        $this->template->arealy = $arealy;
    }
    
    // přidání areálu
    public function actionArealAdd(){
        $form = new Forms\ArealForm($this, 'form');
        $this->template->title = 'Nový areál';
        $this->setView('form');
    }
    
    // upraví areál
    public function actionArealUpd($id_areal){
        $areal = \ArealyModel::getInstance()->areal($id_areal);
        $form = new Forms\ArealForm($this, 'form');
        $form->setDefaults($areal);
        $this->template->title = 'Editace areálu';
        $this->setView('form');
    }
    
    // odstraní areál
    public function actionArealDel($id_areal){
        $areal = \ArealyModel::getInstance()->arealDel($id_areal);
        $this->flashMessage('Areál byl úspěšně odstraněn','success');
        $this->redirect('Admin:arealy');
    }
    
// SPORTOVIŠTĚ
    
    // výpis sportovišť
    public function actionSportoviste() {
        $vp        = new \VisualPaginator($this,'vp');
        $paginator = $vp->getPaginator();
        $paginator->itemsPerPage = 20;
        $paginator->itemCount = count(\SportovisteModel::getInstance()->selectAll());
        $sportoviste = \SportovisteModel::getInstance()->selectAll($paginator->offset,$paginator->itemsPerPage);
        foreach($sportoviste as $key => $sport) {
            $sportoviste[$key]['areal'] = \ArealyModel::getInstance()->areal($sport['id_areal']);
        }
        $this->template->sportoviste = $sportoviste;
    }
    
    // přidání sportoviště
    public function actionSportovisteAdd(){
        $form = new Forms\SportovisteForm($this, 'form');
        $this->template->title = 'Nové sportoviště';
        $this->setView('form');
    }
    
    // upraví sportoviště
    public function actionSportovisteUpd($id_sportoviste){
        $sportoviste = \SportovisteModel::getInstance()->sportoviste($id_sportoviste);
        $form = new Forms\SportovisteForm($this, 'form');
        $form->setDefaults($sportoviste);
        $this->template->title = 'Editace sportoviště';
        $this->setView('form');
    }
    
    // odstraní sportoviště
    public function actionSportovisteDel($id_sportoviste){
        \SportovisteModel::getInstance()->sportovisteDel($id_sportoviste);
        $this->flashMessage('Sportoviště bylo úspěšně odstraněno','success');
        $this->redirect('Admin:arealy');
    }
    
// ČASY (termíny, ve kterých je možné rezervovat sportoviště)
    
    // výpis časů
    public function actionCasy() {
        $vp        = new \VisualPaginator($this,'vp');
        $paginator = $vp->getPaginator();
        $paginator->itemsPerPage = 20;
        $paginator->itemCount = count(\CasyModel::getInstance()->selectAll());
        $casy = \CasyModel::getInstance()->selectAll($paginator->offset,$paginator->itemsPerPage);
        foreach($casy as $key => $cas) {
            $casy[$key]['sportoviste'] = \SportovisteModel::getInstance()->sportoviste($cas['id_sportoviste']);
        }
        $this->template->casy = $casy;
    }
    
    // přidání času
    public function actionCasAdd(){
        $form = new Forms\CasForm($this, 'form');
        $this->template->title = 'Nový čas';
        $this->setView('form');
    }
    
    // upraví čas
    public function actionCasUpd($id_cas){
        $cas = \CasyModel::getInstance()->cas($id_cas);
        $form = new Forms\CasForm($this, 'form');
        $form->setDefaults($cas);
        $this->template->title = 'Editace času';
        $this->setView('form');
    }
    
    // odstraní čas
    public function actionCasDel($id_cas){
        \CasyModel::getInstance()->casDel($id_cas);
        $this->flashMessage('Čas byl úspěšně odstraněn','success');
        $this->redirect('Admin:arealy');
    }    
    
// NEWSLETTER
    
    // newsletter
    public function actionNewsletter() {
        $form = new Forms\NewsletterForm($this, 'form');
        $this->template->title = 'Poslat hromadný e-mail / Newsletter';
        $this->setView('form');
    }

// PLATBY
    
    // výpis plateb
    public function actionPlatby($id_areal = null,$id_sportoviste = null) {
        $vp        = new \VisualPaginator($this,'vp');
        $paginator = $vp->getPaginator();
        $paginator->itemsPerPage = 20;
        $paginator->itemCount = count(\PlatbyModel::getInstance()->selectAll(null,null,$id_sportoviste,$id_areal));
        $platby = \PlatbyModel::getInstance()->selectAll($paginator->offset,$paginator->itemsPerPage,$id_sportoviste,$id_areal);
        foreach($platby as $key => $platba) {
            $sportoviste = \SportovisteModel::getInstance()->sportoviste($platba['id_sportoviste']);
            $platby[$key]['sportoviste'] = $sportoviste;
            if($platba['id_areal']==0) {
                $platby[$key]['areal'] = \ArealyModel::getInstance()->areal($sportoviste['id_areal']);
            }else{
                $platby[$key]['areal'] = \ArealyModel::getInstance()->areal($platba['id_areal']);
            }
        }
        $this->template->platby = $platby;
        
        $arealy = \ArealyModel::getInstance()->selectAll();
        $this->template->arealy = $arealy;
        
        $sportoviste = \SportovisteModel::getInstance()->selectAll();
        $this->template->sportoviste = $sportoviste;
    }
    
    // přidání platbu
    public function actionPlatbaAdd(){
        $form = new Forms\PlatbaForm($this, 'form');
        $this->template->title = 'Nová platba';
        $this->setView('form');
    }
    
    // upraví platbu
    public function actionPlatbaUpd($id_platba){
        $platba = \PlatbyModel::getInstance()->platba($id_platba);
        $form = new Forms\PlatbaForm($this, 'form');
        $form->setDefaults($platba);
        $this->template->title = 'Editace platby';
        $this->setView('form');
    }
    
    // odstraní platbu
    public function actionPlatbaDel($id_platba){
        \PlatbyModel::getInstance()->platbaDel($id_platba);
        $this->flashMessage('Platba byla úspěšně odstraněna','success');
        $this->redirect('Admin:platby');
    }    
    
// ÚČETNICTVÍ
    
    // výpis exportu
    public function actionUcto() {
        $form = new Forms\ExportForm($this,'export');
        
        $prehledy = \PlatbyModel::getInstance()->exportList(20);
        
        foreach ($prehledy as $key => $prehled) {
            $sportoviste = \SportovisteModel::getInstance()->sportoviste($prehled['id_sportoviste']);
            $vytvoril    = \UserModel::getInstance()->user($prehled['id_user']);
            if($prehled['id_sportoviste']==0) {
                $prehledy[$key]['sportoviste'] = 'Všechna sportoviště';
            }else{
                $prehledy[$key]['sportoviste'] = $sportoviste['nazev'];
            }
            $prehledy[$key]['vytvoril']    = $vytvoril['jmeno'].' '.$vytvoril['prijmeni'];
        }
        
        $this->template->prehledy = $prehledy;
    }
    
    // odstraní export
    public function actionExportDel($id_export) {
        \PlatbyModel::getInstance()->exportDel($id_export);
        if(file_exists(WWW_DIR.'/export/'.$id_export.'.xls')) {
            unlink(WWW_DIR.'/export/'.$id_export.'.xls');
        }
        $this->flashMessage('Export byl úspěšně odstraněn','success');
        $this->redirect('Admin:ucto');
    }
    
// ROZVRHY
    
    // přidání rozvrhu
    public function actionRozvrhAdd(){
        $form = new \AdminModule\Forms\RozvrhForm($this, 'form');
        $this->template->title = 'Nový rozvrh';
        $this->setView('form');
    }
    
    // upraví rozvrh
    public function actionRozvrhUpd($id_rozvrh){
        $rozvrh = \RozvrhyModel::getInstance()->rozvrh($id_rozvrh);
        $form = new \AdminModule\Forms\RozvrhForm($this, 'form');
        $form->setDefaults($rozvrh);
        $this->template->title = 'Editace rozvrhu';
        $this->setView('form');
    }
    
    // odstraní rozvrh
    public function handleRozvrhDel($id_rozvrh){
        \RozvrhyModel::getInstance()->rozvrhDel($id_rozvrh);
        $this->flashMessage('Rozvrh byl úspěšně odstraněn','success');
        $this->redirect('this');
    }     
    
    
// CENÍKY
    
    // přidání ceníku
    public function actionCenaKatAdd() {
        $form = new Forms\CenikKatForm($this, 'form');
        $this->template->title = 'Nový ceník';
        $this->setView('form');
    }
    
    // upraví kategorii
    public function actionCenaKatUpd($id_kategorie){
        $kategorie = \CenikyModel::getInstance()->kategorie($id_kategorie);
        $form = new Forms\CenikKatForm($this, 'form');
        $form->setDefaults($kategorie);
        
        $form = new Forms\CenikForm($this, 'cenik');
        unset($kategorie['nazev']);
        $form->setDefaults($kategorie);
        $this->template->title = 'Editace kategorie';
        
        $ceny = \CenikyModel::getInstance()->selectAll($id_kategorie);
        $this->template->ceny  = $ceny;
        $this->setView('cenik');
    }
    
    // odstraní kategorii
    public function handleCenaKatDel($id_kategorie){
        $category = \CenikyModel::getInstance()->cenaKatDel($id_kategorie);
        $this->flashMessage('Ceník byl úspěšně odstraněn','success');
        $this->redirect('this');
    }   
    
    // odstraní položku
    public function handleCenaDel($id_cena){
        \CenikyModel::getInstance()->cenaDel($id_cena);
        $this->flashMessage('Položka byla odstraněna','success');
        $this->redirect('this');
    } 
    
    // upraví položku
    public function actionCenaUpd($id_cena){
        $cenik = \CenikyModel::getInstance()->cena($id_cena);
        $form = new Forms\CenikForm($this, 'form');
        $form->setDefaults($cenik);
        $this->template->title = 'Editace položky';
        $this->setView('form');
    }
    
}

