<?php

namespace Forms;

use Nette\Application\UI;
use Nette\ComponentModel\IContainer;
use Nette\Forms\Form;
use Nette\Mail\Mail;

class RegistraceForm extends UI\Form {

    public function __construct(IContainer $parent = NULL, $name = NULL) {
	parent::__construct($parent, $name);
        
        $user = $this->getPresenter()->getUser();
        
        
        $this->addText('jmeno', 'Jméno:')
                ->addRule(Form::FILLED, 'Zadejte Vaše jméno.');
        
        $this->addText('prijmeni', 'Příjmení:')
                ->addRule(Form::FILLED, 'Zadejte Vaše Příjmení.');
        
        $this->addText('telefon', 'Telefon:')
                ->addRule(Form::FILLED, 'Zadejte Vaše Příjmení.');
        
	$this->addText('email', 'E-mail:')
		->addRule(Form::FILLED, 'Prosím zadajte e-mailovou adresu.')
                ->addRule(Form::EMAIL, 'Zadaná hodnota musí být email.');
        
        // úprava údajú administrátorem bez ověření
        if($user->isInRole('admin')){
            
            $this->addPassword('password', 'Heslo:');

            $role = \UserModel::getInstance()->selectAllRoleForm();
            $this->addSelect('id_role', 'Role:', $role);
        
        }elseif(($user->isLoggedIn())AND(!$user->isInRole('admin'))){
            $this->addPassword('password', 'Heslo:');

        // nový uživatel - probíhá ověření 
        }else{
	$this->addPassword('password', 'Heslo:')
		->addRule(Form::FILLED, 'Prosím zadajte heslo.')
                ->addRule(Form::MIN_LENGTH, 'Heslo musí mít alespoň %d znaky', 3);
        
        $this->addPassword('password2', 'Heslo znovu:')
                ->addRule(Form::FILLED, 'Zadejte heslo znovu.')
                ->addRule(Form::EQUAL, 'Hesla se musí shodovat.', $this['password']);
        
        }
        
        $this->addCheckbox('newsletter','Přeji si zasílat informační e-maily');
        
        $this->addCheckbox('podminky','Souhlasím s obchodními podmínkami')
                ->addRule(Form::FILLED,'Bez souhlasu s obchodními podmínkami nelze registraci dokončit');
        
        $this->addHidden('id_user');
        
	$this->addSubmit('send', 'Odeslat')
                ->setAttribute('class','btn btn-success');
	$this->onSuccess[] = array($this, 'formSubmited');
    }

    public function formSubmited($form) {
        
        $data = $form->getValues();
        
    
    // ÚPRAVA UŽIVATELE  
        
        if($data['id_user'] != null){
            
            // ověříme, že uživatel upravuje sám sebe
            if(($data['id_user'] == $this->getPresenter()->getUser()->getId())OR($this->getPresenter()->getUser()->isInRole('admin'))) {
            
                
                if($data['password']!= ""){
                    $data['password'] = \Authenticator::calculateHash($data['password']);
                }else{
                    unset($data['password']);
                }

                \UserModel::getInstance()->updateUser($data['id_user'],$data);
                

                $this->getPresenter()->flashMessage('Nastavení bylo úspěšně uloženo', 'success');
            }else{
                $this->getPresenter()->flashMessage('Nemáte oprávnění pro tuto akci','error');
                $this->getPresenter()->redirect('Homepage:default');
            }
            
   // NOVÝ UŽIVATEL - REGISTRACE         
            
        }else{
        
        // Ověříme, jestli je login (email) unikátní
        
        if (\UserModel::getInstance()->isLoginUnique($data['email'])) {
		unset($data['password2']);
		$data['password'] = \Authenticator::calculateHash($data['password']);
                
                // Získáme data pro tabulku USER
        
                $data_user = array(
                    'email'     => $data['email'],
                    'password'  => $data['password'],
                    'active'    => 1,
                    'jmeno'     => $data['jmeno'],
                    'prijmeni'  => $data['prijmeni'],
                    'telefon'   => $data['telefon'],
                    'datum'     => new \DateTime
                );
                
                \UserModel::getInstance()->newUser($data_user);
                
                
                $this->getPresenter()->flashMessage('Registrace proběhla v pořádku. Můžete se přihlásit do systému','success');
                $this->getPresenter()->redirect('Areal:areal');
	    } else {
		$this->getPresenter()->flashMessage('Zadaný e-mail je již v systému zaregistrován. Zadejte jiný e-mail', 'error');
	    }
        }
    }

}
