<?php

namespace Forms;

use Nette\Application\UI;
use Nette\ComponentModel\IContainer;
use Nette\Forms\Form;
use Nette\Mail\Mail;

class UserForm extends UI\Form {

    public function __construct(IContainer $parent = NULL, $name = NULL) {
	parent::__construct($parent, $name);
        
        $user = $this->getPresenter()->getUser();
        
        
        $this->addText('jmeno', 'Jméno:')
                ->addRule(Form::FILLED, 'Zadejte Vaše jméno.');
        
        $this->addText('prijmeni', 'Příjmení:')
                ->addRule(Form::FILLED, 'Zadejte Vaše Příjmení.');
        
	$this->addText('email', 'E-mail:')
		->addRule(Form::FILLED, 'Prosím zadajte e-mailovou adresu.')
                ->addRule(Form::EMAIL, 'Zadaná hodnota musí být email.');
        
        // úprava údajú administrátorem bez ověření
        if($user->isInRole('admin')){
            
            $this->addPassword('password', 'Heslo:');

            $role = array(1 => "Administrátor", 2 => "Běžný uživatel", 4 => "Prodejce");
            $this->addSelect('id_role', 'Role:', $role);
            
            $this->addCheckbox('faktura','Může provádět platbu na fakturu');
            
            $this->addCheckbox('karta','Může provádět platbu kartou');
            
            $this->addCheckbox('cela_plocha','Může prodávat neomezeně na celé ploše');
            
            $this->addCheckbox('ucetni', 'Účetní');
            
            $arealy = \ArealyModel::getInstance()->selectAllForm();
            
            $this->addMultiSelect('omezeni','Omezení prodeje',$arealy);
        
        }elseif(($user->isLoggedIn())AND(!$user->isInRole('admin'))){
            $this->addPassword('password', 'Heslo:');

        // nový uživatel - probíhá ověření 
        }else{
	$this->addPassword('password', 'Heslo:')
		->addRule(Form::FILLED, 'Prosím zadajte heslo.')
                ->addRule(Form::MIN_LENGTH, 'Heslo musí mít alespoň %d znaky', 3);
        
        $this->addPassword('password2', 'Heslo znovu:')
                ->addRule(Form::FILLED, 'Zadejte heslo znovu.')
                ->addRule(Form::EQUAL, 'Hesla se musí shodovat.', $this['password']);
        
        }
        
        $this->addHidden('id_user');
        
	$this->addSubmit('send', 'Odeslat')
                ->setAttribute('class','btn btn-success');
	$this->onSuccess[] = array($this, 'formSubmited');
    }

    public function formSubmited($form) {
        
        $data = $form->getValues();
        
    
    // ÚPRAVA UŽIVATELE  
        
        if($data['id_user'] != null){
            
            // ověříme, že uživatel upravuje sám sebe
            if(($data['id_user'] == $this->getPresenter()->getUser()->getId())OR($this->getPresenter()->getUser()->isInRole('admin'))) {
            
                
                if($data['password']!= ""){
                    $data['password'] = \Authenticator::calculateHash($data['password']);
                }else{
                    unset($data['password']);
                }
                
                // omezení prodeje
                \RezervaceModel::getInstance()->deleteOmezeni($data['id_user']);
                foreach($data['omezeni'] as $omezeni) {
                    $zdroj_omezeni = array(
                        'id_user'  => $data['id_user'],
                        'id_areal' => $omezeni
                    );
                    \RezervaceModel::getInstance()->newOmezeni($zdroj_omezeni);
                }
                unset($data['omezeni']);
                
                \UserModel::getInstance()->updateUser($data['id_user'],$data);
                

                $this->getPresenter()->flashMessage('Nastavení bylo úspěšně uloženo', 'success');
            }else{
                $this->getPresenter()->flashMessage('Nemáte oprávnění pro tuto akci','error');
                $this->getPresenter()->redirect('Homepage:default');
            }
            
   // NOVÝ UŽIVATEL - REGISTRACE         
            
        }else{
        
        // Ověříme, jestli je login (email) unikátní
        
        if (\UserModel::getInstance()->isLoginUnique($data['email'])) {
		unset($data['password2']);
		$data['password'] = \Authenticator::calculateHash($data['password']);
                
                // Získáme data pro tabulku USER
        
                $data_user = array(
                    'email'     => $data['email'],
                    'password'  => $data['password'],
                    'active'    => 1,
                    'jmeno'     => $data['jmeno'],
                    'prijmeni'  => $data['prijmeni'],
                    'faktura'   => $data['faktura'],
                    'karta'     => $data['karta'],
                    'cela_plocha' => $data['cela_plocha'],
                    'ucetni'    => $data['ucetni'],
                    'datum'     => new \DateTime
                );
                
                $id_user = \UserModel::getInstance()->newUser($data_user);
                
                // omezení prodeje
                \RezervaceModel::getInstance()->deleteOmezeni($id_user);
                foreach($data['omezeni'] as $omezeni) {
                    $zdroj_omezeni = array(
                        'id_user'  => $id_user,
                        'id_areal' => $omezeni
                    );
                    \RezervaceModel::getInstance()->newOmezeni($zdroj_omezeni);
                }
                
                $this->getPresenter()->flashMessage('Byli jste úspěšně zaregistrováni.','success');
                $this->getPresenter()->redirect('Login:default');
	    } else {
		$this->getPresenter()->flashMessage('Zadaný e-mail je již v systému zaregistrován. Zadejte jiný e-mail', 'error');
	    }
        }
    }

}
