<?php

final class TerminyModel extends BaseModel {

    protected static $instance;
    
    // přidá termín
    public function newTermin($data) {
        self::db()->table('terminy')->insert($data);
        return self::db()->lastInsertId('id_termin');
    }
    
    // vybere všechny termíny
    public function selectAll() {
        return self::db()->query('SELECT * FROM terminy ORDER BY id_termin ASC')->fetchAll();
    }
    
    // upraví termín
    public function updateTermin($id_termin,$data){
        return self::db()->query('UPDATE terminy SET ? WHERE id_termin = ?', $data, $id_termin);
    }
    
    // vybere termín
    public function selectTermin($id_termin) {
        return self::db()->query('SELECT * FROM terminy WHERE id_termin = ?', $id_termin)->fetch();
    }
    
    // odstraní termín
    public function deleteTermin($id_termin) {
        return self::db()->query('DELETE FROM terminy WHERE id_termin = ?', $id_termin);
    }
    
    // vybere termíny podle měsíce (formát měsíce => 00-12)
    public function selectByMonth($datum){
        $datum = explode("-",$datum);
        $mesic = $datum[1];
        return self::db()->query('SELECT * FROM terminy WHERE EXTRACT(MONTH FROM datum) = ?',$mesic)->fetchAll();
    }
    
    // vybere termíny podle ID akce
    public function selectByAkce($id_akce){
        return self::db()->query('SELECT * FROM terminy WHERE id_akce = ? ORDER BY datum ASC',$id_akce)->fetchAll();
    }
    
    // vybere termíny pro formulář
    public function selectAllForm($id_udalost = null) {
        $filtr = '';
        if(isset($id_udalost)) {
            $filtr .= ' AND a.id_udalost = "'.$id_udalost.'"';
        }
        return self::db()->query('SELECT t.id_termin,CONCAT_WS(" ",a.nazev,DATE_FORMAT(t.datum,"%d.%m.%y - %H:%i")) as nazev_datum FROM terminy t, akce a WHERE t.id_akce = a.id_akce '.$filtr.' ORDER BY a.nazev,t.datum')->fetchPairs('t.id_termin','nazev_datum');
    }
    
    // vypíše termíny
    public function selectAllAdmin($offset=null,$limit=null,$od=null,$do=null,$udalost=null,$search=null,$order=null) {
        // stránkování
        if(isSet($offset,$limit)){
            $limit = ' LIMIT '.intval($offset).','.intval($limit);
        } else {
            $limit = '';
        }
        // výpis podle časového zadání
        if(isSet($od)){
            $od = ' AND t.datum >= "'.$od.'"';
        }
        if(isSet($do)){
            $do = ' AND t.datum <= "'.$do.'"';
        }
        // výpis pouze určitého typu události
        if(isSet($udalost)){
            $udalost = ' AND a.id_udalost = '.$udalost;
        }
        // vyhledávání
        if(isSet($search)){
            $hledani = ' AND (a.nazev LIKE "%'.$search.'%" OR a.popis LIKE "%'.$search.'%")';
        }else{
            $hledani = '';
        }
        // řazení
        if(isset($order)) {
            $razeni = ' ORDER BY t.datum DESC';
        }else{
            $razeni = ' ORDER BY t.datum ASC';
        }
        
	return self::db()->query('SELECT a.id_akce,a.nazev as akce,a.popis,a.cena,a.rezervace_aktivni,a.rezervace_zobrazit,a.id_udalost,a.id_sal,a.film_titulky,a.film_3d,a.csfd,a.predplatne,a.obrazek,t.id_termin,t.datum,u.nazev as udalost,s.nazev as sal FROM terminy t,akce a,udalosti u,saly s WHERE t.id_akce = a.id_akce AND a.id_sal = s.id_sal AND a.id_udalost = u.id_udalost '.$od.$do.$udalost.$hledani.$razeni.$limit)->fetchAll();
    }
    
    // vypíše termíny bez kina
    public function selectAllBezKina($offset=null,$limit=null,$od=null,$do=null,$order=null) {
        // stránkování
        if(isSet($offset,$limit)){
            $limit = ' LIMIT '.intval($offset).','.intval($limit);
        } else {
            $limit = '';
        }
        // výpis podle časového zadání
        if(isSet($od)){
            $od = ' AND t.datum >= "'.$od.'"';
        }
        if(isSet($do)){
            $do = ' AND t.datum <= "'.$do.'"';
        }
        // řazení
        if(isset($order)) {
            $razeni = ' ORDER BY t.datum DESC';
        }else{
            $razeni = ' ORDER BY t.datum ASC';
        }
        
	return self::db()->query('SELECT a.id_akce,a.nazev as akce,a.popis,a.cena,a.rezervace_aktivni,a.rezervace_zobrazit,a.id_udalost,a.id_sal,a.csfd,a.predplatne,a.obrazek,t.id_termin,t.datum,u.nazev as udalost,s.nazev as sal FROM terminy t,akce a,udalosti u,saly s WHERE t.id_akce = a.id_akce AND a.id_sal = s.id_sal AND a.id_udalost = u.id_udalost AND u.id_udalost != 1 '.$od.$do.$razeni.$limit)->fetchAll();
    }
    
    // vypíše termíny bez kina
    public function selectAllDsrbk($offset=null,$limit=null,$od=null,$do=null,$order=null) {
        // stránkování
        if(isSet($offset,$limit)){
            $limit = ' LIMIT '.intval($offset).','.intval($limit);
        } else {
            $limit = '';
        }
        // výpis podle časového zadání
        if(isSet($od)){
            $od = ' AND t.datum >= "'.$od.'"';
        }
        if(isSet($do)){
            $do = ' AND t.datum <= "'.$do.'"';
        }
        // řazení
        if(isset($order)) {
            $razeni = ' ORDER BY t.datum DESC';
        }else{
            $razeni = ' ORDER BY t.datum ASC';
        }
        
	return self::db()->query('SELECT a.id_akce,a.nazev as akce,a.popis,a.cena,a.rezervace_aktivni,a.rezervace_zobrazit,a.id_udalost,a.id_sal,a.csfd,a.predplatne,a.obrazek,t.id_termin,t.datum,u.nazev as udalost,s.nazev as sal FROM terminy t,akce a,udalosti u,saly s WHERE t.id_akce = a.id_akce AND a.id_sal = s.id_sal AND a.id_udalost = u.id_udalost AND a.dsrbk = 1'.$od.$do.$razeni.$limit)->fetchAll();
    }
    
    public static function getInstance() {
	if (is_null(self::$instance)) {
	    self::$instance = new self();
	}
	return self::$instance;
    }

}

