<?php

use Nette\Web\User;
use Nette\Component;
use Nette\ComponentContainer;
use Nette\Application\Control;

abstract class BasePresenter extends Nette\Application\UI\Presenter {

    
    public function __construct(Nette\IComponentContainer $parent = NULL, $name = NULL) {
	parent::__construct($parent, $name);
    }

    public function startup() {
	parent::startup();
        
        // načte uživatele
        $user = \Nette\Environment::getUser();
        
        // nastavení do šablony
        $nastaveni = \NastaveniModel::getInstance()->selectAll();
        $this->template->nastaveni = $nastaveni;
        
        // SESSIONS
        if($nastaveni['hlaska']!=''){
            $session = $this->getSession('hlaska');
            if($session->hlaska != 1) {
                $this->template->hlaska = $nastaveni['hlaska'];
            }
            $session->hlaska=1;
            $session->setExpiration(0, 'hlaska');
        }
        
        // areály menu
        $this->template->menu_arealy = \ArealyModel::getInstance()->selectAll(null,null,1);
        
        // stránky menu
        $this->template->menu_pages = \PagesModel::getInstance()->selectAll(null,null,1);
        
        // uživatel do šablony
        $this->template->uzivatel = \UserModel::getInstance()->user($this->getUser()->getId());
        
        // newsletter formulář
        $nl_form = new \Forms\NewsletterForm($this,'newsletterForm');
        $nl_form = $nl_form->getRenderer();
        $nl_form->wrappers['controls']['container'] = NULL;
        $nl_form->wrappers['pair']['container'] = NULL;
        $nl_form->wrappers['label']['container'] = NULL;
        $nl_form->wrappers['control']['container'] = NULL;
	
        $form = new \Forms\LoginForm($this,'login');
        $form = $form->getRenderer();
        $form->wrappers['controls']['container'] = NULL;
        $form->wrappers['pair']['container'] = NULL;
        $form->wrappers['label']['container'] = NULL;
        $form->wrappers['control']['container'] = NULL;
        
    }
    
    // v šabloně zobrazuje 5000000 => 5 000 000 Kč
    protected function createTemplate($class = NULL){
        $template = parent::createTemplate($class);
        $template->registerHelper('currency', 'Helpers::currency');
        return $template;
    }
    
    // odhlášení uživatele
    
    public function handleLogOut() {
	$this->getUser()->logout();
	$this->redirect('this');
    }    
    
    // funkce pro převod na české datum
    protected function datum($datum) {
            $dny["Mon"] = "pondělí";
            $dny["Tue"] = "úterý";
            $dny["Wed"] = "středa";
            $dny["Thu"] = "čtvrtek"; 
            $dny["Fri"] = "pátek"; 
            $dny["Sat"] = "sobota";
            $dny["Sun"] = "neděle";

            $mesice = array(1=>"ledna", "února", "března",
            "dubna", "května", "června",
            "července", "srpna", "září",
            "října", "listopadu", "prosince");
            
            $timestamp = strtotime($datum);
            
            $datum = $dny[Date("D",$timestamp)] . Date(" j. ",$timestamp) . $mesice[(int)Date("m",$timestamp)]. Date(" H:i",$timestamp);
            return $datum;
        }
        
    // funkce pro převod na české datum bez minut a vteřin
    protected function datum2($datum,$short = null) {
            $dny["Mon"] = "pondělí";
            $dny["Tue"] = "úterý";
            $dny["Wed"] = "středa";
            $dny["Thu"] = "čtvrtek"; 
            $dny["Fri"] = "pátek"; 
            $dny["Sat"] = "sobota";
            $dny["Sun"] = "neděle";

            $mesice = array(1=>"ledna", "února", "března",
            "dubna", "května", "června",
            "července", "srpna", "září",
            "října", "listopadu", "prosince");
            
            $timestamp = strtotime($datum);
            
            $datum = $dny[Date("D",$timestamp)] . Date(" j. ",$timestamp) . $mesice[(int)Date("m",$timestamp)];
            
            // pouze den v týdnu
            if($short!=null) {
                $datum = $dny[Date("D",$timestamp)];
            }
            return $datum;
        }  
        
    // funkce pro převod na české datum bez minut a vteřin
    protected function datum3($datum,$short = null) {
            $dny["Mon"] = "pondělí";
            $dny["Tue"] = "úterý";
            $dny["Wed"] = "středa";
            $dny["Thu"] = "čtvrtek"; 
            $dny["Fri"] = "pátek"; 
            $dny["Sat"] = "sobota";
            $dny["Sun"] = "neděle";
            
            $timestamp = strtotime($datum);
            
            $datum = $dny[Date("D",$timestamp)] . Date(" j. ",$timestamp) . Date("n. y",$timestamp);
            
            // pouze den v týdnu
            if($short!=null) {
                $datum = $dny[Date("D",$timestamp)];
            }
            return $datum;
        }

    
    // kalendář
    protected function createComponentKalendar() {
        return new \Components\CalendarControl();
    }
    
    // rezervace
    protected function createComponentRezervace() {
        return new \Components\RezervaceControl();
    }
    
    // rezervace - výpis všech sportovišť na den
    protected function createComponentRezervaceDen() {
        return new \Components\RezervaceDenControl();
    }
        
}

class Helpers {
    public static function currency($value) {
        return str_replace(" ", "\xc2\xa0", number_format($value, 0, "", " ")) . "\xc2\xa0Kč";
    }
}

\Nette\Application\UI\Form::extensionMethod('addMultiUpload', function(\Nette\Application\UI\Form $form, $name, $label = NULL) {
    $form[$name] = new \Nette\Forms\Controls\MultiUploadControl($label);
    return $form[$name];
});